@@ -315,7 +315,7 @@ class Manifest(object):
     """
     __slots__ = [
         'description', 'brief',
-        'author', 'license', 'license_url', 'url',
+        'author', 'license', 'licenses', 'license_url', 'url',
         'depends', 'rosdeps', 'platforms',
         'exports', 'version',
         'status', 'notes',
@@ -332,6 +332,7 @@ class Manifest(object):
             self.license = self.license_url = \
             self.url = self.status = \
             self.version = self.notes = ''
+        self.licenses = []
         self.depends = []
         self.rosdeps = []
         self.exports = []
@@ -397,6 +398,7 @@ def parse_manifest_file(dirpath, manifest_name, rospack=None):
         manifest.description = p.description
         manifest.author = ', '.join([('Maintainer: %s' % str(m)) for m in p.maintainers] + [str(a) for a in p.authors])
         manifest.license = ', '.join(p.licenses)
+        manifest.licenses = p.licenses
         if p.urls:
             manifest.url = str(p.urls[0])
         manifest.version = p.version
@@ -430,8 +432,11 @@ def parse_manifest_file(dirpath, manifest_name, rospack=None):
 
         return manifest
 
-    with open(filename, 'r') as f:
-        return parse_manifest(manifest_name, f.read(), filename)
+    with open(filename, 'rb') as f:
+        data = f.read()
+    if sys.version_info[0] >= 3:
+        data = data.decode('utf-8')
+    return parse_manifest(manifest_name, data, filename)
 
 
 def parse_manifest(manifest_name, string, filename='string'):
