@@ -138,7 +138,9 @@ class LsbDetect(OsDetector):
     """
     def __init__(self, lsb_name, get_version_fn=None):
         self.lsb_name = lsb_name
-        if hasattr(distro, "linux_distribution"):
+        if distro.__name__ == "distro":
+            self.lsb_info = (distro.id(), distro.version(), distro.codename())
+        elif hasattr(distro, "linux_distribution"):
             self.lsb_info = distro.linux_distribution(full_distribution_name=0)
         elif hasattr(distro, "dist"):
             self.lsb_info = distro.dist()
@@ -169,16 +171,17 @@ class Debian(LsbDetect):
 
     def get_codename(self):
         if self.is_os():
-            v = self.get_version()
-            if v.startswith('7.'):
-                return 'wheezy'
-            if v.startswith('8.'):
-                return 'jessie'
-            if v.startswith('9.'):
-                return 'stretch'
-            if v.startswith('10.'):
-                return 'buster'
-            return ''
+            v = self.get_version().split('.', 1)[0]
+            return {
+                '7': 'wheezy',
+                '8': 'jessie',
+                '9': 'stretch',
+                '10': 'buster',
+                '11': 'bullseye',
+                '12': 'bookworm',
+                '13': 'trixie',
+                'unstable': 'sid',
+            }.get(v, '')
 
 
 class FdoDetect(OsDetector):
@@ -242,6 +245,26 @@ class OpenEmbedded(OsDetector):
         raise OsNotDetected('called in incorrect OS')
 
 
+class Conda(OsDetector):
+    """
+    Detect Conda.
+    """
+    def is_os(self):
+        return "ROS_OS_OVERRIDE" in os.environ and \
+            (os.environ["ROS_OS_OVERRIDE"].lower().startswith("robostack") or
+             os.environ["ROS_OS_OVERRIDE"].lower().startswith("conda"))
+
+    def get_version(self):
+        if self.is_os():
+            return ""
+        raise OsNotDetected('called in incorrect OS')
+
+    def get_codename(self):
+        if self.is_os():
+            return ""
+        raise OsNotDetected('called in incorrect OS')
+
+
 class OpenSuse(OsDetector):
     """
     Detect OpenSuse OS.
@@ -292,7 +315,8 @@ _osx_codename_map = {
  '10.13': 'high sierra',
  '10.14': 'mojave',
  '10.15': 'catalina',
- '11': 'big sur'
+ '11': 'big sur',
+ '12': 'monterey'
 }
 
 
@@ -645,11 +669,13 @@ OS_OPENEMBEDDED = 'openembedded'
 OS_OPENSUSE = 'opensuse'
 OS_OPENSUSE13 = 'opensuse'
 OS_ORACLE = 'oracle'
+OS_CONDA = 'conda'
 OS_TIZEN = 'tizen'
 OS_SAILFISHOS = 'sailfishos'
 OS_OSX = 'osx'
 OS_POP = 'pop'
 OS_QNX = 'qnx'
+OS_RASPBIAN = 'raspbian'
 OS_RHEL = 'rhel'
 OS_ROCKY = 'rocky'
 OS_SLACKWARE = 'slackware'
@@ -686,6 +712,7 @@ OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse-tumbleweed"))
 OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse-leap"))
 OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse"))
 OsDetect.register_default(OS_ORACLE, FdoDetect("ol"))
+OsDetect.register_default(OS_CONDA, Conda())
 OsDetect.register_default(OS_TIZEN, FdoDetect("tizen"))
 OsDetect.register_default(OS_SAILFISHOS, FdoDetect("sailfishos"))
 OsDetect.register_default(OS_OSX, OSX())
