@@ -31,33 +31,38 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
-import sys
-import unittest
+
 import yaml
 
+
 def get_test_path():
     return os.path.abspath(os.path.join(os.path.dirname(__file__), 'rosdistro'))
 
+
 def get_etc_path():
     return os.path.abspath(os.path.join(os.path.dirname(__file__), 'fakeetcros'))
 
+
 def test_distro_uri():
     from rospkg.distro import distro_uri
-    assert distro_uri('groovy') == "http://ros-dry-releases.googlecode.com/svn/trunk/distros/groovy.rosdistro"
-    
+    assert distro_uri('groovy') == "http://svn.code.sf.net/p/ros-dry-releases/code/trunk/distros/groovy.rosdistro"
+
+
 def test_current_distro_codename():
     import rospkg.environment
     from rospkg.distro import current_distro_codename
-    assert 'awesome' == current_distro_codename(env={'ROS_DISTRO':'awesome'})
-    env={rospkg.environment.ROS_ETC_DIR: get_etc_path()}
+    assert 'awesome' == current_distro_codename(env={'ROS_DISTRO': 'awesome'})
+    env = {rospkg.environment.ROS_ETC_DIR: get_etc_path()}
     val = current_distro_codename(env=env)
     assert 'rosawesome' == current_distro_codename(env=env), val
-    
+
+
 def test__current_distro_electric():
     from rospkg.distro import _current_distro_electric
     # tripwire, not allowed to throw
     _current_distro_electric()
-    
+
+
 def test__current_distro_electric_parse_roscore():
     from rospkg.distro import _current_distro_electric_parse_roscore
     roscore_file = os.path.join(get_test_path(), 'roscore-electric.xml')
@@ -66,26 +71,27 @@ def test__current_distro_electric_parse_roscore():
     assert 'electric' == val, val
 
     bad_roscore_file = os.path.join(get_test_path(), 'roscore-bad.xml')
-    assert None == _current_distro_electric_parse_roscore(bad_roscore_file)
-    
+    assert _current_distro_electric_parse_roscore(bad_roscore_file) is None
+
     no_roscore_file = os.path.join(get_test_path(), 'non-existent.xml')
-    assert None == _current_distro_electric_parse_roscore(no_roscore_file)
+    assert _current_distro_electric_parse_roscore(no_roscore_file) is None
+
 
 def xtest_Distro_dback(self):
     # TODO: better unit tests. For now this is mostly a tripwire
-    from rospkg.distro import Distro, DistroStack, Variant
+    from rospkg.distro import DistroStack
     distros = load_Distros_dback()
     dback = distros['diamondback']
     r = 'diamondback'
     v = 'r8596'
 
     self.assertEquals(r, dback.release_name)
-    self.assertEquals(v, dback.version)        
+    self.assertEquals(v, dback.version)
 
     # make sure ros got assigned and is correct
     ros = DistroStack('ros', dback_ros_rules, dback_versions['ros'], r, v)
     self.assertEquals(ros, dback.ros)
-    self.assertEquals(ros, dback.stacks['ros'])        
+    self.assertEquals(ros, dback.stacks['ros'])
 
     # make sure the variants are configured
     self.assert_('base' not in dback.variants)
@@ -95,37 +101,36 @@ def xtest_Distro_dback(self):
     ros_base_stacks = ['ros', 'ros_comm']
     self.assertEquals(ros_base_stacks, ros_base.stack_names)
 
-    robot = dback.variants['robot'] #extends ros-base
+    robot = dback.variants['robot']  # extends ros-base
     self.assertEquals(set(['ros-base']), set(robot.extends))
     robot_stacks = ['common_msgs', 'common', 'diagnostics', 'driver_common', 'geometry', 'robot_model', 'executive_smach']
-    self.assertEquals(set(ros_base_stacks+robot_stacks), set(robot.stack_names))
+    self.assertEquals(set(ros_base_stacks + robot_stacks), set(robot.stack_names))
     self.assertEquals(set(robot_stacks), set(robot.stack_names_explicit))
 
-    mobile = dback.variants['mobile'] #extends robot
+    mobile = dback.variants['mobile']  # extends robot
     mobile_stacks = ['navigation', 'slam_gmapping']
-    self.assertEquals(set(ros_base_stacks+robot_stacks+mobile_stacks), set(mobile.stack_names))
+    self.assertEquals(set(ros_base_stacks + robot_stacks + mobile_stacks), set(mobile.stack_names))
     self.assertEquals(set(mobile_stacks), set(mobile.stack_names_explicit))
 
-    viz = dback.variants['viz'] 
+    viz = dback.variants['viz']
     self.assertEquals([], viz.extends)
-    viz_stacks = ['visualization_common', 'visualization'] 
+    viz_stacks = ['visualization_common', 'visualization']
     self.assertEquals(set(viz_stacks), set(viz.stack_names))
     self.assertEquals(set(viz_stacks), set(viz.stack_names_explicit))
 
-    desktop = dback.variants['desktop'] #robot, rviz
+    desktop = dback.variants['desktop']  # robot, rviz
     self.assertEquals(set(['robot', 'viz']), set(desktop.extends))
     desktop_stacks = ['ros_tutorials', 'common_tutorials', 'geometry_tutorials', 'visualization_tutorials']
-    self.assertEquals(set(ros_base_stacks+robot_stacks+viz_stacks+desktop_stacks), set(desktop.stack_names))
+    self.assertEquals(set(ros_base_stacks + robot_stacks + viz_stacks + desktop_stacks), set(desktop.stack_names))
     self.assertEquals(set(desktop_stacks), set(desktop.stack_names_explicit))
 
     simulator_stacks = ['simulator_stage', 'simulator_gazebo', 'physics_ode']
     perception_stacks = ['image_common', 'image_transport_plugins', 'image_pipeline', 'laser_pipeline', 'perception_pcl', 'vision_opencv']
-    desktop_full = dback.variants['desktop-full'] 
+    desktop_full = dback.variants['desktop-full']
     self.assertEquals(set(['desktop', 'mobile', 'perception', 'simulators']), set(desktop_full.extends))
-    self.assertEquals(set(ros_base_stacks+robot_stacks+mobile_stacks+perception_stacks+simulator_stacks+desktop_stacks+viz_stacks), set(desktop_full.stack_names))
+    self.assertEquals(set(ros_base_stacks + robot_stacks + mobile_stacks + perception_stacks + simulator_stacks + desktop_stacks + viz_stacks), set(desktop_full.stack_names))
     self.assertEquals([], desktop_full.stack_names_explicit)
 
-
     # make sure we loaded the stacks
     stack_names = ['common', 'common_msgs', 'navigation']
     for s in stack_names:
@@ -144,12 +149,14 @@ def xtest_Distro_dback(self):
     val = DistroStack(s, dback_geometry_rules, dback_versions[s], r, v)
     self.assertEquals(val, dback.stacks[s])
 
+
 def test_expand_rule():
     from rospkg.distro import expand_rule
     assert 'foo' == expand_rule('$STACK_NAME', 'foo', 'version', 'release')
     assert 'version' == expand_rule('$STACK_VERSION', 'foo', 'version', 'release')
     assert 'release' == expand_rule('$RELEASE_NAME', 'foo', 'version', 'release')
-    assert 'foo-version-release' == expand_rule('$STACK_NAME-$STACK_VERSION-$RELEASE_NAME', 'foo', 'version', 'release')    
+    assert 'foo-version-release' == expand_rule('$STACK_NAME-$STACK_VERSION-$RELEASE_NAME', 'foo', 'version', 'release')
+
 
 default_rules = {}
 default_rules['git'] = {'git': {'anon-uri': 'https://github.com/ipa320/$STACK_NAME.git',
@@ -159,6 +166,7 @@ default_rules['git'] = {'git': {'anon-uri': 'https://github.com/ipa320/$STACK_NA
                                 'uri': 'git@github.com:ipa320/$STACK_NAME.git'}}
 rule = default_rules['git']
 
+
 def test_DistroStack():
     from rospkg.distro import DistroStack
     s = DistroStack('stack', 'version', 'electric', rule)
@@ -172,16 +180,17 @@ def test_DistroStack():
     assert s.vcs_config.get_branch('distro', True) == ('https://github.com/ipa320/stack.git', 'electric')
     assert s.vcs_config.get_branch('release', False) == ('git@github.com:ipa320/stack.git', 'stack-version'), s.vcs_config.get_branch('release', False)
     assert s.vcs_config.get_branch('release', True) == ('https://github.com/ipa320/stack.git', 'stack-version')
-    
+
     assert s == s
     assert s == DistroStack('stack', 'version', 'electric', rule)
     assert s != 'stack'
-    assert s != DistroStack('stack2', 'version', 'electric', rule)    
+    assert s != DistroStack('stack2', 'version', 'electric', rule)
     assert s != DistroStack('stack', 'version2', 'electric', rule)
     assert s != DistroStack('stack', 'version', 'dback', rule)
     rule2 = rule.copy()
     rule2['git']['uri'] == 'foo'
-    assert s != DistroStack('stack', 'version', 'dback', rule2)  
+    assert s != DistroStack('stack', 'version', 'dback', rule2)
+
 
 def test_Variant():
     from rospkg.distro import Variant
@@ -202,6 +211,7 @@ def test_Variant():
     assert set(v.get_stack_names(False)) == set(['arm_navigation', 'octomap_mapping', 'physics_ode', 'perception_pcl', 'pr2_controllers',
                                                  'control', 'pr2_mechanism', 'pr2_common'])
 
+
 def test_Distro():
     from rospkg.distro import Distro, Variant, DistroStack
 
@@ -226,6 +236,7 @@ def test_Distro():
     assert stacks == d.stacks
     assert {'stack': s} == d.released_stacks
 
+
 dback_ros_rules = {'svn': {'dev': 'https://code.ros.org/svn/ros/stacks/$STACK_NAME/trunk',
                            'distro-tag': 'https://code.ros.org/svn/ros/stacks/$STACK_NAME/tags/$RELEASE_NAME',
                            'release-tag': 'https://code.ros.org/svn/ros/stacks/$STACK_NAME/tags/$STACK_NAME-$STACK_VERSION'},
@@ -236,12 +247,13 @@ dback_rospkg_rules = {'svn': {'dev': 'https://code.ros.org/svn/ros-pkg/stacks/$S
                       'repo': 'ros-pkg'}
 
 dback_versions = {
-  'common': '1.3.3',
-  'common_msgs': '1.3.5',
-  'geometry': '1.3.1',
-  'navigation': '1.3.1',
-  'ros':'1.4.0',
-  }
+    'common': '1.3.3',
+    'common_msgs': '1.3.5',
+    'geometry': '1.3.1',
+    'navigation': '1.3.1',
+    'ros': '1.4.0',
+}
+
 
 def test_load_distro_bad_data():
     from rospkg import ResourceNotFound
@@ -249,19 +261,22 @@ def test_load_distro_bad_data():
     try:
         load_distro('bad')
         assert False
-    except ResourceNotFound: pass
+    except ResourceNotFound:
+        pass
     for i in range(1, 10):
         if i == 4:
             # currently non-existent stacks in variants are not determinable
             continue
-        filename = 'bad%s.rosdistro'%(i)
+        filename = 'bad%s.rosdistro' % (i)
         try:
             d = get_test_path()
             p = os.path.join(d, filename)
             load_distro(p)
-            assert False, "should have raised: %s"%(filename)
-        except InvalidDistro: pass
-    
+            assert False, "should have raised: %s" % (filename)
+        except InvalidDistro:
+            pass
+
+
 def test_load_distro_variants():
     # test with no and empty variants (issue found in fuerte bringup)
     from rospkg.distro import load_distro
@@ -271,7 +286,8 @@ def test_load_distro_variants():
         distro = load_distro(p)
         assert distro.release_name == 'simple', distro.release_name
         assert set(distro.variants.keys()) == set([])
-    
+
+
 def test_distro_to_rosinstall():
     from rospkg.distro import distro_to_rosinstall, load_distro
     d = get_test_path()
@@ -287,7 +303,8 @@ def test_distro_to_rosinstall():
     data = distro_to_rosinstall(distro, 'devel', variant_name=None, implicit=False, released_only=False, anonymous=True)
     assert len(data) == 1
     assert data[0] == dict(svn={'uri': url, 'local-name': 'stack1'})
-    #TODO: need more complete tests with more complicated files
+    # TODO: need more complete tests with more complicated files
+
 
 def test_load_distro_simple():
     from rospkg.distro import load_distro, Distro
@@ -295,10 +312,10 @@ def test_load_distro_simple():
     p = os.path.join(d, 'simple.rosdistro')
     distro = load_distro(p)
     assert isinstance(distro, Distro)
-    
+
     assert distro.release_name == 'simple', distro.release_name
     assert distro.version == '1', distro.version
-    assert yaml.load(open(p)) == distro.raw_data, distro.raw_data
+    assert yaml.safe_load(open(p)) == distro.raw_data, distro.raw_data
     assert set(distro.variants.keys()) == set(['base'])
     assert set(distro.stacks.keys()) == set(['stack1'])
 
@@ -307,6 +324,7 @@ def test_load_distro_simple():
     assert stack1.vcs_config.get_branch('distro', False) == ('https://simple.com/svn/tags/distros/simple/stacks/stack1', None)
     assert stack1.vcs_config.get_branch('release', False) == ('https://simple.com/svn/tags/stacks/stack1/stack1-0.3.0', None)
 
+
 def test_load_distro_diamondback():
     from rospkg.distro import load_distro, Distro
     d = get_test_path()
@@ -316,22 +334,23 @@ def test_load_distro_diamondback():
 
     assert distro.release_name == 'diamondback', distro.release_name
     assert distro.version == 'r8596', distro.version
-    assert yaml.load(open(p)) == distro.raw_data, distro.raw_data
+    assert yaml.safe_load(open(p)) == distro.raw_data, distro.raw_data
     assert set(distro.variants.keys()) == set(diamondback_variants)
     assert set(distro.stacks.keys()) == set(diamondback_stacks), set(distro.stacks.keys()) ^ set(diamondback_stacks)
 
     assert distro.variants['ros-base'].extends == []
     retval = distro.variants['ros-base'].get_stack_names(True)
     assert retval == ['ros', 'ros_comm'], retval
-    assert distro.variants['ros-base'].get_stack_names(False) == ['ros', 'ros_comm']    
+    assert distro.variants['ros-base'].get_stack_names(False) == ['ros', 'ros_comm']
     assert set(distro.variants['ros-full'].get_stack_names(True)) == set(['ros', 'ros_comm', 'rx', 'documentation'])
-    
+
     assert distro.stacks['common'].version == '1.3.3'
     assert distro.stacks['common'].vcs_config.get_branch('devel', True) == ('https://code.ros.org/svn/ros-pkg/stacks/common/trunk', None)
 
+
 def test__load_variants():
     from rospkg.distro import _load_variants
-    raw_data = yaml.load("""variants:
+    raw_data = yaml.safe_load("""variants:
 - ros-base:
     stacks: [ros, ros_comm]
 - ros-full:
@@ -353,7 +372,7 @@ def test__load_variants():
     variants = _load_variants(raw_data, stacks)
     assert set(variants.keys()) == set(['ros-base', 'ros-full', 'viz', 'robot', 'desktop']), variants.keys()
     assert variants['ros-base'].extends == []
-    assert variants['ros-full'].extends == ['ros-base']    
+    assert variants['ros-full'].extends == ['ros-base']
     assert variants['desktop'].extends == ['robot', 'viz', 'ros-full']
 
     assert set(variants['ros-base'].get_stack_names(True)) == set(['ros', 'ros_comm'])
@@ -364,7 +383,8 @@ def test__load_variants():
 
     assert set(variants['desktop'].get_stack_names(True)) == set(stacks.keys())
     assert set(variants['desktop'].get_stack_names(False)) == set(['ros_tutorials', 'common_tutorials'])
-    
+
+
 diamondback_stacks = [
     'pr2_web_apps', 'octomap_mapping', 'motion_planning_environment', 'robot_calibration',
     'sound_drivers', 'joystick_drivers', 'ros',
